@@ -155,7 +155,7 @@ class cGAN():
                                                            max_to_keep=5)
 
     def fit(self,
-            input_domain,
+            source_domain,
             target_domain,
             epochs,
             batch_size,
@@ -188,7 +188,7 @@ class cGAN():
         if self.generator_optimizer is None:
             raise ModelNotCompiledError("use conGAN.compile() first.")
         if mlflow:
-            import mlflow
+            import mlflow  # pylint: disable=import-outside-toplevel
 
         # Retrace workaround @function signature only tensors.
         step = tf.Variable(initial_step, name="step", dtype=tf.int64)
@@ -203,16 +203,15 @@ class cGAN():
         for epoch in range(epochs):
             step_float = 0
             start = time.time()
-            for input_images, target_images in zip(input_domain,
+            for input_images, target_images in zip(source_domain,
                                                    target_domain):
-                generated_images, source_images, target_images = self.train_step(
-                    input_images, target_images, step, max_outputs,
-                    file_writer)
+                imgs = self.train_step(input_images, target_images, step,
+                                       file_writer)
                 # TODO Workaround. summary image & gpu usage
-                with file_writer.as_default():
-                    tf.summary.image("generated", generated_images, step=step)
-                    tf.summary.image("source", input_images, step=step)
-                    tf.summary.image("target", target_images, step=step)
+                with file_writer.as_default():  # pylint: disable=not-context-manager
+                    tf.summary.image("source", imgs[0], step=step)
+                    tf.summary.image("target", imgs[1], step=step)
+                    tf.summary.image("fake_target", imgs[2], step=step)
 
                 file_writer.flush()
                 progbar.update(current=(step_float))
@@ -274,8 +273,7 @@ class cGAN():
             self.discriminator.save(os.path.join(model_dir, "discriminator"))
 
     @tf.function
-    def train_step(self, source_images, target_images, step, max_outputs,
-                   file_writer):
+    def train_step(self, source_images, target_images, step, file_writer):
         """Decorated function (@tf.function) that creates a callable tensorflow
         graph from a python function.
         """
@@ -284,19 +282,18 @@ class cGAN():
             # Record gradients for generator and discriminator for each seperate
             # training step.
             with tf.GradientTape() as gen_tape, tf.GradientTape() as disc_tape:
-                generated_images = self.generator(source_images, training=True)
-                disc_target = self.discriminator(
+                fake_target = self.generator(source_images, training=True)
+                disc_real_target = self.discriminator(
                     [source_images, target_images], training=True)
-                disc_generated = self.discriminator(
-                    [source_images, generated_images], training=True)
+                disc_fake_target = self.discriminator(
+                    [source_images, fake_target], training=True)
 
-                gen_loss = self.generator_loss(disc_generated,
-                                               generated_images, target_images,
-                                               self.l1_weight)
+                gen_loss = self.generator_loss(disc_fake_target, fake_target,
+                                               target_images, self.l1_weight)
                 tf.summary.scalar("generator_loss", gen_loss, step=step)
 
-                disc_loss = self.discriminator_loss(disc_target,
-                                                    disc_generated)
+                disc_loss = self.discriminator_loss(disc_real_target,
+                                                    disc_fake_target)
                 tf.summary.scalar("discriminator_loss", disc_loss, step=step)
 
             gradients_of_generator = gen_tape.gradient(
@@ -328,11 +325,12 @@ class cGAN():
             self.discriminator_optimizer.apply_gradients(
                 zip(gradients_of_discriminator,
                     self.discriminator.trainable_variables))
+            imgs = [source_images, target_images, fake_target]
             # Piece of shit workaround.
-            return generated_images, source_images, target_images
+            return imgs
 
     @staticmethod
-    def discriminator_loss(real_output, fake_output):
+    def discriminator_loss(real, fake):
         """This method quantifies how well the discriminator is able to
         distinguish real images from fakes. It compares the discriminator's
         predictions on real images to an array of 1s, and the discriminator's
@@ -345,9 +343,9 @@ class cGAN():
         # This method returns a helper function to compute cross entropy loss.
         cross_entropy = tf.keras.losses.BinaryCrossentropy(from_logits=True)
         # Compares real images to tensors of 1 -> if real output 1s
-        real_loss = cross_entropy(tf.ones_like(real_output), real_output)
+        real_loss = cross_entropy(tf.ones_like(real), fake)
         # Compares generated images to tensors of 0 -> if generated output 0s
-        fake_loss = cross_entropy(tf.zeros_like(fake_output), fake_output)
+        fake_loss = cross_entropy(tf.zeros_like(fake), fake)
 
         total_loss = real_loss + fake_loss
         return total_loss
